middleware

package
v0.0.0-...-6d8caf4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Logger

func Logger(logger *slog.Logger) func(next asynq.Handler) asynq.Handler

Logger is a task middleware that prints a log line when a task is started and when a task finishes.

Types

This section is empty.

Jump to